module Bitstream
  module Utils

    include AcceptedFormats

    def clean_tmpfiles(workdir,files)
      files.each do |f|
        delete_file f
      end
      delete_dir workdir
    end

    def tmpdir_path(id)
      tmpdir = "/tmp/#{id}/"
      create_dir tmpdir
      return tmpdir
    end

    def create_dir(dirname)
      FileUtils.mkdir_p(dirname) unless File.directory?(dirname)
    end

    def delete_dir(dir)
      FileUtils.rmdir(dir) if File.directory?(dir)
    end

    def delete_file(file)
      FileUtils.rm(file) if File.exist?(file)
    end

    def public_dir
      @public_dir ||= Rails.root.join('public')
    end

    def get_accepted_bitstreams(filename,retrieve_link,workdir)

      file_format = get_file_extname filename

      accepted_files = []

      if accepted_formats.include? file_format or accepted_archive_formats.include? file_format
        begin
          file = workdir + filename
          download_bitstream(retrieve_link,file)
        rescue Exception => e
          puts "#{method_log_tag} #{e}"
        else
          if accepted_archive_formats.include? file_format
            extract_accepted_bitstreams(file,workdir).each do |f|
              accepted_files << f
            end
            delete_file file
          else
            accepted_files << file
          end
        end
      end

      return accepted_files
    end

    def extract_accepted_bitstreams(archive_file,workdir)

      return [] if archive_file.nil?

      extracted_files = []

      puts "#{method_log_tag} Extracting accepted files out from '#{get_file_basename(archive_file)}'"
      begin
        Archive.read_open_filename(archive_file) do |archive|
          while entry = archive.next_header
            if accepted_formats.include? get_file_extname(entry.pathname)
              filename = get_file_basename(entry.pathname)
              file = workdir + filename
              begin
                File.open(file, 'wb') do |f|
                  archive.read_data(1024) do |d|
                   f << d
                  end
                end
              rescue Exception => e
                puts "#{method_log_tag} #{e}
                    \r#{method_log_tag} ERROR: Some error occurred while extracting file '#{filename}'"
              else
                puts "#{method_log_tag} SUCCESS: Extracted '#{filename}' to '#{file}'"
                extracted_files << file
              end
            end
          end
        end
      rescue Exception => e
        puts "#{method_log_tag} #{e}
            \r#{method_log_tag} ERROR: Some error occurred while extracting files from '#{get_file_basename(archive_file)}'"
      end

      return extracted_files
    end

    def download_bitstream(url,output)
      puts "#{method_log_tag} Downloading bitstream: '#{url}' => '#{output}'"
      begin
        c = Curl::Easy.new(url)
        c.ssl_verify_peer = false
        c.ssl_verify_host = false
        File.open(output, 'wb') do |f|
          c.on_body {|data| f << data; data.size }
          c.perform
        end
      rescue Exception => e
        raise "#{method_log_tag} #{e}
            \r#{method_log_tag} ERROR: Some error occurred during file download."
      else
        return true
      end
    end

    def method_log_tag
      return "[#{caller_locations(1,1)[0].label}]"
    end

  end
end
