module OrientDb
  module Methods
    module EdgeMethods

      include Log::Logging

      # unique = set true if should exist only one edge between two ids
      # out = set true if the edges should come out of the #{id} and into #{o.id} (FROM #{id} TO #{o.id}), set false for the other way around (FROM #{o.id} TO #{id}) 
      def create_edges_from_array(edge_class, id, array, unique=false, out=true)
        edges = []
        array.each do |o|
          unless unique && edge_exists?(edge_class, id, o.id)
            if out
              edges << create_edge(edge_class, id, o.id)
            else
              edges << create_edge(edge_class, o.id, id)
            end
          end
        end
        edges
      end

      ##
      # Count the number of edges existent
      def get_in_edges_count(edge_class, id)
        result = connection.query "SELECT in('#{edge_class}').size() AS COUNT FROM #{id}"
        result.first["COUNT"].to_i
      end

      def create_edge(edge_class, from_id, to_id)
        qry = "CREATE EDGE #{edge_class.to_s} FROM #{from_id} TO #{to_id}"
        logger.create qry
        connection.command qry
      end

      def create_and_set_edge(edge_class, from_id, to_id, values={})
        query = "CREATE EDGE #{edge_class} FROM #{from_id} TO #{to_id} CONTENT #{values.to_json}"
        logger.create query
        connection.command query
      end

      def destroy_edge(edge_class, from_id, to_id)
        connection.command "DELETE EDGE #{edge_class} FROM #{from_id} TO #{to_id}"
      end

      def get_edges_end(edge_class, type, vertex_id)
        connection.query sprintf("SELECT expand(%s('%s')) FROM %s", type, edge_class, vertex_id)
      end

      def get_edges(edge_class, type, vertex_id)
        connection.query sprintf("SELECT * FROM #{edge_class} WHERE #{type} = #{vertex_id}")
      end

      def set_values_edge(edge_id, values={})
        connection.command "UPDATE #{edge_id} CONTENT #{values.to_json}"
      end

      def edge_exists?(edge_class, from_id, to_id)
        edge = connection.query sprintf("SELECT outE('%s') FROM %s WHERE out('%s') CONTAINS %s", edge_class, from_id, edge_class, to_id)
        !edge.empty?
      end

    end
  end
end
