namespace :thumbnail do

  desc "Generate Thumbnails"
  task :generate => :environment do
    generate
  end

  namespace :generate do
    task :force => :environment do
      generate(true)
    end
  end

  private

  def generate(force = false)
    include RepositoriesProxy

    # Quantity of items fetched on each iteration
    limit = 500

    # Start point from where items will be fetched
    offset = 0

    loop do

      begin
        # Get items from dspace (from offset to offset+limit)
        items = learning_object_repository.all_from_offset_to_limit(offset,limit)
      rescue
        # Sleeps for a while to wait database's recovery
        sleep(30.seconds)
        # Goes to next iteration to retry
        next
      else
        # Terminate loop if there are no more items to import
        break if items.empty?

        items.each do |item|
          ThumbnailGeneratorWorker.perform_async(item.id) if (item.thumbnail.blank? || force)
        end

        # Increment offset, to get new items on next iteration
        offset += limit
      end
    end
  end

end
