require 'test_helper'

class CollectionTest < ActiveSupport::TestCase

  test 'collection is invalid when name attribute is empty' do
    collection = Collection.new
    assert !collection.valid?
  end

  test 'collection is valid when name attribute is not empty' do
    collection = Collection.new(name: 'Minha coleção de teste')
    assert collection.valid?
  end

  test 'append learning objects to collection' do
    collection = Collection.new(name: 'Minha coleção de teste')
    collection.add LearningObject.new
    collection.add LearningObject.new

    assert_count 2, collection.learning_objects
  end

  test 'remove learning object from collection' do
    lo1 = LearningObject.new(id: '#45:2')
    collection = Collection.new(name: 'Minha coleção de teste')
    collection.add lo1
    collection.add LearningObject.new(id: '#43:34')
    assert_count 2, collection.learning_objects

    collection.remove lo1
    assert_count 1, collection.learning_objects
  end

  test 'serialize collection for orientdb' do
    collection = Collection.new(name: 'Minha coleção de teste')
    assert_equal(build_collection_hash(collection), collection.to_orientdb_hash)
    #collection.add LearningObject.new(id: '#43:34')
    #collection.add LearningObject.new(id: '#43:53')
    #assert_equal({"@class" => "Collection", "created_at" => "2015-11-18 16:10:52", "last_modified" => "2015-11-18 16:10:52", "learning_objects" => ['#43:34', '#43:53'], "privacy" => "private", "name" => "Minha coleção de teste"}, collection.to_orientdb_hash)
  end

  private

  def build_collection_hash(collection)
    {
        "@class" => "Collection",
        "created_at" => collection.created_at,
        "last_modified" => collection.last_modified,
        "learning_objects" => [],
        "privacy" => collection.privacy,
        "name" => collection.name
    }
  end

end