require 'test_helper'

class ComplaintTest < ActiveSupport::TestCase
  should validate_presence_of :user
  should validate_presence_of :object
  should validate_presence_of :message

  test 'serialize for orientdb' do
    complaint = Complaint.new(
        user: User.new(rid: '#14:15'),
        object: LearningObject.new(id: '#16:43'),
        message: Complaint.copyrights,
        description: 'teste',
        created_at: DateTime.now.strftime("%Y-%m-%d %H:%M:%S")
    )

    expected_hash = {"created_at" => complaint.created_at.to_s, "description" => complaint.description, "message" => complaint.message.to_s}
    assert_equal(expected_hash, complaint.to_orientdb_hash)
  end

  test 'should returns copyright message' do
    assert_complaint_message Complaint.copyrights
  end

  test 'should returns ofensive content message' do
    assert_complaint_message Complaint.ofensive_content
  end

  test 'should returns ofensive user message' do
    assert_complaint_message Complaint.ofensive_user
  end

  test 'should returns fake user message' do
    assert_complaint_message Complaint.fake_user
  end

  private

  def assert_complaint_message(complaint_message)
    assert_instance_of ComplaintMessage, complaint_message
  end
end
